Struct FieldKey
Source pub struct FieldKey(pub String);
Performs copy-assignment from
source.
Read more
Attempt to parse a generic type into FieldKey
This will always work for any generic type that implements the
ToString trait so it can be safely unwrapped
Example
let uuid = Uuid::new_v4();
let key = FieldKey::parse_from(uuid).unwrap();
Attempt to parse FieldKey into generic type T
Example
let key = FieldKey::String("d5a47b74-bff6-4dc5-9c7c-2558bd98a70b");
let uuid = key.parse_into<Uuid>().unwrap();
Formats the value using the given formatter.
Read more
Formats the value using the given formatter.
Read more
Unescapes the escaped string in reverse order
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
Converts the given value to a
String.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.